==> reddit-0.0.0.tar.gz: reddit-0.0.0/src/reddit_priv.h <==
/*  Copyright (C) 2011 Ben Asselstine

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Library General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/
#ifndef REDDIT_PRIV_H
#define REDDIT_PRIV_H 1

#include <curl/curl.h>
#include <glib.h>
#include "story.h"

struct reddit_state_t
{
  int logged_in;
  char *username;
  CURL *curl;
  FILE *out;
  struct reddit_story_t *stories;
  int num_stories;
  char *command; //current command we're working on.
  int story_number; //current story number we're looking at.
  int whats; //what tab we're on.
  char *subreddit; //what subreddit we're in.
  gchar *browser_binary; //where the browser program is living 
  gchar *links_binary; //where the links program is living (for html2text)
  char *modhash; //the last modhash we saw.
  char *page; //what page we're on.
  int columns; //how many columns are on our screen.
};

int reddit_load_and_show_stories (struct reddit_state_t *state, char *page, int *response);
void reddit_reshow_stories (struct reddit_state_t *state);
char * reddit_construct_url (struct reddit_state_t *state, char *page);
int argp_help_check (int argc, char **argv);
int reddit_update_modhash (struct reddit_state_t *state);
void reddit_line (struct reddit_state_t *state);

#define REDDIT_SITE             "www.reddit.com"
#define REDDIT_COOKIEJAR        "/tmp/" PACKAGE ".crumbs"
#endif

==> reddit-0.0.1.tar.gz: reddit-0.0.1/src/reddit_priv.h <==
/*  Copyright (C) 2011 Ben Asselstine

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU Library General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
*/
#ifndef REDDIT_PRIV_H
#define REDDIT_PRIV_H 1

#include <curl/curl.h>
#include <glib.h>
#include "story.h"

struct reddit_state_t
{
  int logged_in;
  char *username;
  CURL *curl;
  FILE *out;
  struct reddit_story_t *stories;
  int num_stories;
  char *command; //current command we're working on.
  int story_number; //current story number we're looking at.
  int whats; //what tab we're on.
  char *subreddit; //what subreddit we're in.
  gchar *browser_binary; //where the browser program is living 
  gchar *browser_options; //what options to give to the browser program
  gchar *links_binary; //where the links program is living (for html2text)
  char *modhash; //the last modhash we saw.
  char *page; //what page we're on.
  int columns; //how many columns are on our screen.
};

int reddit_load_and_show_stories (struct reddit_state_t *state, char *page, int whats, char *subreddit, int *response);
void reddit_reshow_stories (struct reddit_state_t *state);
char * reddit_construct_url (struct reddit_state_t *state, char *page, int whats, char *subreddit);
int argp_help_check (int argc, char **argv);
int reddit_update_modhash (struct reddit_state_t *state);
void reddit_line (struct reddit_state_t *state);
void reddit_banner (struct reddit_state_t *state, char *title);
int reddit_history(struct reddit_state_t *state);
int reddit_warranty (struct reddit_state_t *state);
int reddit_browser (struct reddit_state_t *state);
int reddit_set_browser (struct reddit_state_t *state, char *value);
int reddit_browser_options (struct reddit_state_t *state);
int reddit_set_browser_options (struct reddit_state_t *state, char *value);
void reddit_unknown_command (struct reddit_state_t *state);
int reddit_set_history (struct reddit_state_t *state, char *value);
int reddit_post (struct reddit_state_t *state, char *action, char *post, int *resp, char **msg);

#define REDDIT_SITE             "www.reddit.com" //no prefix, no slashes.
#define REDDIT_COOKIEJAR        "/tmp/" PACKAGE ".crumbs"
#endif
